@@ -24,16 +24,17 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv8-a -O3 -pipe -fno-plt -fno-semantic-interposition '
-           '-march=armv8-a -O3 -pipe -fno-plt -march=armv8-a -O3 -pipe '
-           '-fno-plt',
+           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -march=armv8-a -O3 -pipe '
+           '-fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fno-plt '
-                     '-fno-semantic-interposition',
+ 'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fstack-protector-strong '
+                     '-fno-plt -fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -49,7 +50,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv8-a "
-                "-O3 -pipe -fno-plt -fno-semantic-interposition' "
+                '-O3 -pipe -fstack-protector-strong -fno-plt '
+                "-fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
@@ -109,7 +111,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -643,10 +645,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv8-a -O3 -pipe '
-                             '-fno-plt -fno-semantic-interposition '
-                             '-march=armv8-a -O3 -pipe -fno-plt -march=armv8-a '
-                             '-O3 -pipe -fno-plt -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-fstack-protector-strong -fno-plt '
+                             '-fno-semantic-interposition -march=armv8-a -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-march=armv8-a -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt -std=c99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -654,19 +658,21 @@ build_time_vars = {'ABIFLAGS': '',
                              '-D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv8-a -O3 -pipe -fno-plt -fno-semantic-interposition '
-              '-march=armv8-a -O3 -pipe -fno-plt -march=armv8-a -O3 -pipe '
-              '-fno-plt',
+              '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -march=armv8-a -O3 -pipe '
+              '-fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv8-a -O3 -pipe -fno-plt '
-                   '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-                   '-fno-plt -march=armv8-a -O3 -pipe -fno-plt -std=c99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wall -march=armv8-a -O3 -pipe -fstack-protector-strong '
+                   '-fno-plt -fno-semantic-interposition -march=armv8-a -O3 '
+                   '-pipe -fstack-protector-strong -fno-plt -march=armv8-a -O3 '
+                   '-pipe -fstack-protector-strong -fno-plt -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
@@ -683,9 +689,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv8-a -O3 -pipe -fno-plt '
+                        '-O3 -Wall -march=armv8-a -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
                         '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-                        '-fno-plt -march=armv8-a -O3 -pipe -fno-plt -std=c99 '
+                        '-fstack-protector-strong -fno-plt -march=armv8-a -O3 '
+                        '-pipe -fstack-protector-strong -fno-plt -std=c99 '
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
